;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;; See the file LICENCE for licence information.
(defpackage :cl-l10n-tests
  (:shadowing-import-from :cl-l10n format formatter)
  (:use :cl :regression-test :cl-l10n))

(in-package :cl-l10n-tests)

(rem-all-tests)
(deftest load-locs 
    (progn (locale "en_ZA") (locale "sv_SE") (locale "en_GB")
           (locale "en_US") (locale "af_ZA") t)
  t)

;; Format number tests
(deftest number.1
    (format nil "~v:/cl-l10n:format-number/" "en_ZA" 1000)
  "1,000")

(deftest number.2
    (format nil "~v:@/cl-l10n:format-number/" "en_ZA" 1000)
  "1000")

(deftest number.3
    (format nil "~v/cl-l10n:format-number/" "en_ZA" 1000)
  "1,000.00")

(deftest number.4
    (format nil "~v/cl-l10n:format-number/" "sv_SE" 1000)
  "1 000,00")

(deftest number.5
    (format nil "~v:/cl-l10n:format-number/" "sv_SE" 1000)
  "1 000")

(deftest number.6
    (format nil "~v:/cl-l10n:format-number/" "sv_SE" 1/2)
  "0,5")

(deftest number.7
    (format nil "~v:/cl-l10n:format-number/" "en_GB" 100.12312d0)
  "100.12312")


;; Money tests
(deftest money.1
    (format nil "~v:/cl-l10n:format-money/" "en_ZA" 1000)
  "ZAR 1,000.00")


(deftest money.2
    (format nil "~v@/cl-l10n:format-money/" "en_ZA" 1000)
  "R1000.00")

(deftest money.3
    (format nil "~v:@/cl-l10n:format-money/" "en_ZA" 1000)
  "ZAR 1000.00")

(deftest money.4
    (format nil "~v:/cl-l10n:format-money/" "sv_SE" 1000)
  "1 000,00 SEK")


(deftest money.5
    (format nil "~v@/cl-l10n:format-money/" "sv_SE" 1000)
  "1000,00 kr")

(deftest money.6
    (format nil "~v:@/cl-l10n:format-money/" "sv_SE" 1000)
  "1000,00 SEK")


;; Time tests
(deftest time.1
    (format nil "~v:@/cl-l10n:format-time/" "en_ZA" 3091103120)
  "Sun 14 Dec 1997 17:45:20 +0200")

(deftest time.2
    (format nil "~v:@/cl-l10n:format-time/" "sv_SE" 3091103120)
  "sn 12 Dec 1997 17.45.20")

(deftest time.3
    (format nil "~v/cl-l10n:format-time/" "en_US" 3091103120)
  "05:45:20 ")

(deftest time.4
    (format nil "~v:/cl-l10n:format-time/" "en_US" 3091103120)
  "12/14/1997")

(deftest time.5
    (format nil "~v@/cl-l10n:format-time/" "en_US" 3091103120)
  "17:45:20 ")

(deftest time.6
    (format nil "~v@/cl-l10n:format-time/" "sv_SE" 3091103120)
  "17.45.20")

(defparameter *full-test* 
  (format nil "%% %a %A %b %B %c %C %d %D %e %F %g %G %h %H %I ~
%j %k %l %m %M %n %N %p %P %r %R %S %t %T %u %w %x %X %y %z %Z"))

(deftest time.7 
    (format nil "~v,v/cl-l10n:format-time/" "en_ZA" *full-test* 3091103120)
  "% Sun Sunday Dec December Sun Dec 14 17:45:20 +0200 1997 19 14 12/14/97 12 1997-12-14 97 1997 Dec 17 05 348 17  5 12 45 
 000000000   17:45:20  17:45 20 	 17:45:20 7 5 12/14/97 17:45:20 97 +0200 +0200")


(deftest time.8
    (format nil "~v,v/cl-l10n:format-time/" "en_US" *full-test* 3091103120)
  "% Sun Sunday Dec December Sun Dec 14 17:45:20 +0200 1997 19 14 12/14/97 12 1997-12-14 97 1997 Dec 17 05 348 17  5 12 45 
 000000000   17:45:20  17:45 20 	 17:45:20 7 5 12/14/97 17:45:20 97 +0200 +0200")

(deftest time.9
    (format nil "~v,v/cl-l10n:format-time/" "sv_SE" *full-test* 3091103120)
"% sn sndag Dec December sn Dec 14 17:45:20 +0200 1997 19 14 12/14/97 12 1997-12-14 97 1997 dec 17 05 348 17  5 12 45 
 000000000   17:45:20  17:45 20 	 17:45:20 7 5 12/14/97 17:45:20 97 +0200 +0200")
  

;; i18n tests 
(defvar *my-bundle* (make-instance 'bundle))

(add-resources (*my-bundle* "af_")
  "howareyou" "Hoe lyk it")

(add-resources (*my-bundle* "en")
  "howareyou" "How are you")

(deftest i18n.1 
    (gettext "howareyou" *my-bundle* "en_ZA")
  "How are you")

(deftest i18n.2
    (gettext "howareyou" *my-bundle* "af_ZA")
  "Hoe lyk it")

;; format
(deftest format.1
    (format nil "~v:@U" "en_ZA" 3091103120)
  "Sun 14 Dec 1997 17:45:20 +0200")

(deftest format.2
    (format nil "~v:n" "en_ZA" 1000)
  "1,000")

(deftest format.3
    (format nil "~v:@m" "sv_SE" 1000)
  "1000,00 SEK")

;; formatter
(deftest formatter.1
    (format nil (formatter "~v:@U") "en_ZA" 3091103120)
  "Sun 14 Dec 1997 17:45:20 +0200")

(deftest formatter.2
    (format nil (formatter "~v:n") "en_ZA" 1000)
  "1,000")

(deftest formatter.3
    (format nil (formatter "~v:@m") "sv_SE" 1000)
  "1000,00 SEK")


;; parse-number
(deftest parse-number.1
    (parse-number (format nil "~vn" "af_ZA" -1001231.5) "af_ZA")
  -1001231.5)

(deftest parse-number.2
    (parse-number (format nil "~v@:n" "en_ZA" -1001231.5) "en_ZA")
  -1001231.5)


;; EOF